/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-28 16:17:55.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.utils;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;

/**
 * @author: QMTH
 * @since: 2018/11/28
 */
public class ElectronUtils {
    private static final Logger log = LoggerFactory.getLogger(ElectronUtils.class);
    private static final String WIN_PREFIX = "cmd /c ";
    private static final String LINUX_PREFIX = "./";

    /**
     * 将URL响应内容转为PDF文件
     */
    public static boolean toPdf(String profile, String cmdDir, String targetUrl, String pdfPath) {
        if (StringUtils.isBlank(profile)) {
            log.warn("[toPdf] spring.profiles.active must be not empty.");
            return false;
        }

        if (StringUtils.isBlank(targetUrl)) {
            log.warn("[toPdf] targetUrl must be not empty.");
            return false;
        }

        if (StringUtils.isBlank(pdfPath)) {
            log.warn("[toPdf] pdfPath must be not empty.");
            return false;
        }

        if (StringUtils.isBlank(cmdDir)) {
            log.warn("[toPdf] cmdDir must be not empty.");
            return false;
        }

        File dir = new File(cmdDir);
        if (!dir.exists()) {
            FileUtils.makeDirs(cmdDir);
        }

        final String parentDir = dir.getParent();

        if (isWindows()) {
            //Windows带盘符路径，去掉首个"/"字符
            if (pdfPath.indexOf(":") > 0 && pdfPath.startsWith("/")) {
                pdfPath = pdfPath.replaceFirst("/", "");
            }

            String command = String.format("cmd /c electron-pdf %s %s -p A3 -l true -e view-ready", targetUrl, pdfPath);
            return executeCommand(command, "GBK");
        } else {
            //Linux
            String command = String.format("%s/electron-pdf-%s.sh %s %s", parentDir, profile, targetUrl, pdfPath);
            return executeCommand(command, "UTF-8");
        }
    }

    /**
     * 执行命令
     */
    private static boolean executeCommand(String command, String charsetName) {
        log.debug("Execute Command:" + command);

        Process process;
        try {
            process = Runtime.getRuntime().exec(command);
        } catch (IOException e) {
            log.error(e.getMessage(), e);
            return false;
        }

        try (BufferedReader out = new BufferedReader(new InputStreamReader(process.getInputStream(), charsetName));
             BufferedReader err = new BufferedReader(new InputStreamReader(process.getErrorStream(), charsetName));) {

            String outStr;
            while ((outStr = out.readLine()) != null) {
                log.debug(outStr);
            }

            String errStr;
            while ((errStr = err.readLine()) != null) {
                log.debug("err:" + errStr);
            }

            int exitCode = process.waitFor();
            if (exitCode == 0) {
                log.debug("Execute Command Success.");
                return true;
            }

            log.warn("Execute Command Error. exitCode:" + exitCode);
        } catch (IOException e) {
            log.error(e.getMessage(), e);
        } catch (InterruptedException e) {
            log.error(e.getMessage(), e);
            Thread.currentThread().interrupt();
        } finally {
            if (process != null) {
                process.destroy();
            }
        }
        return false;
    }

    public static boolean isWindows() {
        String os = System.getProperty("os.name").toLowerCase();
        if (os.contains("windows") || os.startsWith("win")) {
            return true;
        }
        return false;
    }

}