package cn.com.qmth.examcloud.core.print.api.controller;

import cn.com.qmth.examcloud.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.common.Result;
import cn.com.qmth.examcloud.core.print.service.ExamStructureService;
import cn.com.qmth.examcloud.core.print.service.bean.examstructure.ExamStructureInfo;
import cn.com.qmth.examcloud.core.print.service.bean.examstructure.ExamStructureQuery;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

/**
 * 考试结构相关接口
 *
 * @author: weiwenhai
 * @since: 2018.10.30
 * @author: QMTH
 * @update: 2018/11/22
 */
@RestController
@Api(tags = "考试结构相关接口")
@RequestMapping("${$rmp.ctrl.print}/examStructure")
public class ExamStructureController extends ControllerSupport {
    @Autowired
    private ExamStructureService examStructureService;

    @PostMapping("/list")
    @ApiOperation(value = "获取考试结构信息列表(分页)")
    public Page<ExamStructureInfo> getExamStructureList(@RequestBody ExamStructureQuery query) {
        return examStructureService.getExamStructureList(query);
    }

    @PostMapping("/{orgId}/{examId}")
    @ApiOperation(value = "获取某个考试结构信息")
    public ExamStructureInfo getExamStructure(@PathVariable Long orgId, @PathVariable Long examId) {
        return examStructureService.getExamStructure(orgId, examId);
    }

    @PostMapping("/save")
    @ApiOperation(value = "保存某个考试结构信息")
    public Result saveExamStructure(@RequestBody ExamStructureInfo info) {
        examStructureService.saveExamStructure(info);
        return Result.success();
    }

    @PostMapping("/clone")
    @ApiOperation(value = "复用某个考试结构信息")
    public Result cloneExamStructure(@RequestBody ExamStructureInfo info) {
        examStructureService.cloneExamStructure(info);
        return Result.success();
    }

    @PostMapping("/delete/{ids}")
    @ApiOperation(value = "删除某个考试结构信息")
    public Result deleteExamStructure(@PathVariable Long[] ids) {
        examStructureService.deleteExamStructure(ids);
        return Result.success();
    }

}