/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-22 15:29:29.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.core.print.common.jpa.SearchBuilder;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.ProjectBackupSetting;
import cn.com.qmth.examcloud.core.print.repository.ProjectBackupSettingRepository;
import cn.com.qmth.examcloud.core.print.service.ProjectBackupSettingService;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.ProjectBackupSettingConvert;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.ProjectBackupSettingInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Optional;

import static cn.com.qmth.examcloud.core.print.common.Constants.SYS_CODE_500;

/**
 * @author: QMTH
 * @since: 2018/10/17
 */
@Service
public class ProjectBackupSettingServiceImpl implements ProjectBackupSettingService {
    private static final Logger log = LoggerFactory.getLogger(ProjectBackupSettingServiceImpl.class);
    @Autowired
    private ProjectBackupSettingRepository projectBackupSettingRepository;

    @Override
    public ProjectBackupSetting getProjectBackupSettingById(Long projectId) {
        Check.isNull(projectId, "项目ID不能为空！");
        ProjectBackupSetting setting = projectBackupSettingRepository.findByProjectId(projectId);
        if (setting == null) {
            throw new StatusException(SYS_CODE_500, "当前项目的备份设置信息不存在！");
        }
        return setting;
    }

    @Override
    public void saveProjectBackupSetting(ProjectBackupSettingInfo info) {
        Check.isNull(info, "备份设置的信息不能为空！");
        Check.isNull(info.getProjectId(), "备份设置的项目ID不能为空！");

        if (info.getNeedEachPkg()) {
            Check.isNull(info.getEachPkgPercent(), "每袋备份比例不能为空！");
            Check.isNull(info.getEachPkgMax(), "每袋备份最大值不能为空！");
            Check.isNull(info.getEachPkgMin(), "每袋备份最小值不能为空！");
        }

        if (info.getNeedAlonePkg()) {
            Check.isNull(info.getGroupType(), "单独备份归集类型不能为空！");
            Check.isNull(info.getAlonePkgPercent(), "单独备份比例不能为空！");
            Check.isNull(info.getAlonePkgMax(), "单独备份最大值不能为空！");
            Check.isNull(info.getAlonePkgMin(), "单独备份最小值不能为空！");
        }

        Specification<ProjectBackupSetting> spec = SearchBuilder.EQ("projectId", info.getProjectId());
        Optional<ProjectBackupSetting> optional = projectBackupSettingRepository.findOne(spec);

        ProjectBackupSetting setting = ProjectBackupSettingConvert.of(info);
        if (optional.isPresent()) {
            //存在记录时，则修改
            ProjectBackupSetting baseSetting = optional.get();
            setting.setId(baseSetting.getId());
            setting.setCreationTime(baseSetting.getCreationTime());
            setting.setUpdateTime(new Date());
        }

        //否则，新增记录
        projectBackupSettingRepository.save(setting);
    }

    @Override
    public void removeProjectBackupSettingById(Long projectId) {
        Check.isNull(projectId, "项目ID不能为空！");
        projectBackupSettingRepository.deleteByProjectId(projectId);
    }

}